(wrap-packer packer {:keys [binary?] :as opts})Experimental, please test carefully and report any issues!
Returns Sente packer that wraps another with gzip compression.
Needs js/CompressionStream browser support.
If packer takes+returns platform bytes: binary? should be true.
If packer takes+returns platform strings: binary? should be false.
:max-uncompressed-bytes defaults to 64 MiB to bound gzip expansion.
Set it to nil to disable the limit.
Experimental, please test carefully and report any issues! Returns Sente packer that wraps another with gzip compression. Needs `js/CompressionStream` browser support. If `packer` takes+returns platform bytes: `binary?` should be true. If `packer` takes+returns platform strings: `binary?` should be false. `:max-uncompressed-bytes` defaults to 64 MiB to bound gzip expansion. Set it to nil to disable the limit.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |